@@ -101,14 +101,14 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "annotated.html",
-"core_8h.html#a47e11e8e3cb9a31107f8f42308314b27",
-"global_8h.html#a74a7902607d041b9ebea8ad223af7a2d",
-"impl-node_8c.html#a47f2e62c0dbebc787052c165afcada0e",
-"link_8h.html#a7859f6eb040fead1673d0214b83b445ba369af04b8025470a27c313640bbb4bc0",
-"permission_8h.html#aa6b729cf828ec6417f5ba997560fda2b",
-"stream_8h.html#a9ceaca6fc9acd9a1af080258d763fb82",
-"structpw__factory__methods.html#aa3d553e1352e95ecc6870f28cb98a5fe",
-"structpw__protocol__marshal.html#a84d23417562653ce0c3f833914745b4b"
+"core_8h.html#a3c4c5529b9bb6c9188053bdf1604c2e0",
+"global_8h.html#a3e5b2dd59d6cf7c614c3ed24b041a8b7",
+"impl-node_8c.html#a2a6221b4e79357e3d2620faf0e2c7623",
+"link_8h.html#a72d8e03483fd111c9a9eb87aac3897a2",
+"permission_8h.html#a50224a8e3d16e9baa4be58183fec502f",
+"stream_8h.html#a087a686c66c04e54742cc94c7a5e4e68",
+"structpw__factory__events.html#a2408a490257998e8aec63c452b450024",
+"structpw__protocol__events.html#af7bb9abb40f974acecda6bb2c6ad5cad"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
